==> edulab-lms-1.3.zip: edulab-lms/storage/framework/views/68d836c313ae3365e4434ae05e09d3c8.php <==
<?php
    $rolePermissions = isset($rolePermissions) && is_array($rolePermissions) ? $rolePermissions : [];
?>

<?php if (isset($component)) { $__componentOriginald7f77a02f879fd4954ea3c39c4e952cb = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginald7f77a02f879fd4954ea3c39c4e952cb = $attributes; } ?>
<?php $component = Modules\LMS\View\Components\Dashboard\Layout::resolve([] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('dashboard-layout'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Modules\LMS\View\Components\Dashboard\Layout::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes([]); ?>
     <?php $__env->slot('title', null, []); ?> <?php echo e(isset($role) ? translate('Edit') : translate('Create')); ?> <?php echo e(translate('Role')); ?> <?php $__env->endSlot(); ?>
    <!-- BREADCRUMB -->
    <?php if (isset($component)) { $__componentOriginalcf27f2c2c873893339708d5fdeeb6984 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginalcf27f2c2c873893339708d5fdeeb6984 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => '7ee9c4f86007ba41bc79bbfab1cd8a68::admin.breadcrumb','data' => ['title' => ''.e(isset($role) ? 'Edit' : 'Create').' Role','pageTo' => 'Role','backUrl' => ''.e(route('role.index')).'']] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('portal::admin.breadcrumb'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['title' => ''.e(isset($role) ? 'Edit' : 'Create').' Role','page-to' => 'Role','back-url' => ''.e(route('role.index')).'']); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginalcf27f2c2c873893339708d5fdeeb6984)): ?>
<?php $attributes = $__attributesOriginalcf27f2c2c873893339708d5fdeeb6984; ?>
<?php unset($__attributesOriginalcf27f2c2c873893339708d5fdeeb6984); ?>
<?php endif; ?>
<?php if (isset($__componentOriginalcf27f2c2c873893339708d5fdeeb6984)): ?>
<?php $component = $__componentOriginalcf27f2c2c873893339708d5fdeeb6984; ?>
<?php unset($__componentOriginalcf27f2c2c873893339708d5fdeeb6984); ?>
<?php endif; ?>
    <form action="<?php echo e(isset($role) ? route('role.update', $role->id) : route('role.store')); ?>" method="post"
        class="form">
        <?php echo csrf_field(); ?>
        <?php if(isset($role)): ?>
            <?php echo method_field('PUT'); ?>
        <?php endif; ?>
        <div class="card">
            <div class="grid grid-cols-12 gap-x-4">
                <div class="col-span-full md:col-span-6">
                    <div class="leading-none">
                        <label for="title" class="form-label"> <?php echo e(translate('Name')); ?> <span
                                class="require-field"><b>*</b></span></label>
                        <input type="text" id="title" name="name" value="<?php echo e($role->name ?? ''); ?>"
                            class="form-input">
                        <span class="text-danger error-text name_err"></span>
                    </div>

                    <input type="hidden" name="guard_name" value="admin" class="form-input">
                    <div class="mt-5 mb-3">
                        <label class="text-lg"> <?php echo e(translate('Permission')); ?> </label>
                    </div>
                </div>
            </div>

            <div class="grid grid-cols-12 gap-x-4 h-[600px] overflow-y-scroll">
                <?php $__currentLoopData = $permissions; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $key => $permission): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                    <div class="col-span-full md:col-span-4">
                        <div class="group-permission">
                            <div class="flex items-center gap-2 mb-2">
                                <input id="check-s-<?php echo e($key); ?>" type="checkbox"
                                    class="check check-primary-solid check-md check-enable-parent">
                                <label for="check-s-<?php echo e($key); ?>" class="card-title text-lg">
                                    <?php echo e($key); ?></label>
                            </div>
                            <div class="ml-10">
                                <?php $__currentLoopData = $permission; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $value): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                    <div class="flex items-center gap-2 mb-2">
                                        <input id="check-s-<?php echo e($value->id); ?>" type="checkbox"
                                            class="check check-primary-solid check-md check-enable-child"
                                            name="permissions[]" value="<?php echo e($value->name); ?>"
                                            <?php echo e(in_array($value->id, $rolePermissions) ? 'checked' : ''); ?>>
                                        <label for="check-s-<?php echo e($value->id); ?>"
                                            class="form-label text-base m-0"><?php echo e($value->name); ?></label>
                                    </div>
                                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                            </div>
                        </div>
                    </div>
                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
            </div>
            <div class="flex justify-end">
                <button type="submit" class="btn b-solid btn-primary-solid dk-theme-card-square">
                    <?php echo e(isset($role) ? translate('Update') : translate('Save')); ?>

                </button>
            </div>
        </div>
    </form>
 <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginald7f77a02f879fd4954ea3c39c4e952cb)): ?>
<?php $attributes = $__attributesOriginald7f77a02f879fd4954ea3c39c4e952cb; ?>
<?php unset($__attributesOriginald7f77a02f879fd4954ea3c39c4e952cb); ?>
<?php endif; ?>
<?php if (isset($__componentOriginald7f77a02f879fd4954ea3c39c4e952cb)): ?>
<?php $component = $__componentOriginald7f77a02f879fd4954ea3c39c4e952cb; ?>
<?php unset($__componentOriginald7f77a02f879fd4954ea3c39c4e952cb); ?>
<?php endif; ?>
<?php /**PATH D:\www\edulab\Modules\Roles\resources\views\roles\form.blade.php ENDPATH**/ ?>

==> edulab-lms_v1.4.zip: edulab-lms/storage/framework/views/68d836c313ae3365e4434ae05e09d3c8.php <==
<?php
    $rolePermissions = isset($rolePermissions) && is_array($rolePermissions) ? $rolePermissions : [];
?>

<?php if (isset($component)) { $__componentOriginald7f77a02f879fd4954ea3c39c4e952cb = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginald7f77a02f879fd4954ea3c39c4e952cb = $attributes; } ?>
<?php $component = Modules\LMS\View\Components\Dashboard\Layout::resolve([] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('dashboard-layout'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Modules\LMS\View\Components\Dashboard\Layout::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes([]); ?>
     <?php $__env->slot('title', null, []); ?> <?php echo e(isset($role) ? translate('Edit') : translate('Create')); ?> <?php echo e(translate('Role')); ?> <?php $__env->endSlot(); ?>
    <!-- BREADCRUMB -->
    <?php if (isset($component)) { $__componentOriginalcf27f2c2c873893339708d5fdeeb6984 = $component; } ?>
<?php if (isset($attributes)) { $__attributesOriginalcf27f2c2c873893339708d5fdeeb6984 = $attributes; } ?>
<?php $component = Illuminate\View\AnonymousComponent::resolve(['view' => '7ee9c4f86007ba41bc79bbfab1cd8a68::admin.breadcrumb','data' => ['title' => ''.e(isset($role) ? 'Edit' : 'Create').' Role','pageTo' => 'Role','backUrl' => ''.e(route('role.index')).'']] + (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag ? $attributes->all() : [])); ?>
<?php $component->withName('portal::admin.breadcrumb'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php if (isset($attributes) && $attributes instanceof Illuminate\View\ComponentAttributeBag): ?>
<?php $attributes = $attributes->except(\Illuminate\View\AnonymousComponent::ignoredParameterNames()); ?>
<?php endif; ?>
<?php $component->withAttributes(['title' => ''.e(isset($role) ? 'Edit' : 'Create').' Role','page-to' => 'Role','back-url' => ''.e(route('role.index')).'']); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginalcf27f2c2c873893339708d5fdeeb6984)): ?>
<?php $attributes = $__attributesOriginalcf27f2c2c873893339708d5fdeeb6984; ?>
<?php unset($__attributesOriginalcf27f2c2c873893339708d5fdeeb6984); ?>
<?php endif; ?>
<?php if (isset($__componentOriginalcf27f2c2c873893339708d5fdeeb6984)): ?>
<?php $component = $__componentOriginalcf27f2c2c873893339708d5fdeeb6984; ?>
<?php unset($__componentOriginalcf27f2c2c873893339708d5fdeeb6984); ?>
<?php endif; ?>
    <form action="<?php echo e(isset($role) ? route('role.update', $role->id) : route('role.store')); ?>" method="post"
        class="form">
        <?php echo csrf_field(); ?>
        <?php if(isset($role)): ?>
            <?php echo method_field('PUT'); ?>
        <?php endif; ?>
        <div class="card">
            <div class="grid grid-cols-12 gap-x-4">
                <div class="col-span-full md:col-span-6">
                    <div class="leading-none">
                        <label for="title" class="form-label"> <?php echo e(translate('Name')); ?> <span
                                class="require-field"><b>*</b></span></label>
                        <input type="text" id="title" name="name" value="<?php echo e($role->name ?? ''); ?>"
                            class="form-input">
                        <span class="text-danger error-text name_err"></span>
                    </div>

                    <input type="hidden" name="guard_name" value="admin" class="form-input">
                    <div class="mt-5 mb-3">
                        <h6 class="card-title text-lg"> <?php echo e(translate('Select Permission')); ?> </h6>
                    </div>
                </div>
            </div>

            <div class="grid grid-cols-12 gap-7 h-full max-h-[600px] overflow-y-scroll">
                <?php $__currentLoopData = $permissions; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $key => $permission): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                    <div class="col-span-full sm:col-span-6 lg:col-span-4 xl:col-span-3">
                        <div class="group-permission h-full dk-border-one rounded-10 dk-theme-card-square p-3">
                            <div class="flex items-center gap-2 border-b border:dk-border-one pb-3">
                                <input id="check-s-<?php echo e($key); ?>" type="checkbox"
                                    class="check check-primary-solid check-md check-enable-parent">
                                <label for="check-s-<?php echo e($key); ?>" class="card-title text-base font-medium leading-none mt-0.5">
                                    <?php echo e($key); ?></label>
                            </div>
                            <div class="mt-3">
                                <?php $__currentLoopData = $permission; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $value): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                    <div class="flex items-center gap-2 mb-2">
                                        <input id="check-s-<?php echo e($value->id); ?>" type="checkbox"
                                            class="check check-primary-solid check-sm check-enable-child"
                                            name="permissions[]" value="<?php echo e($value->name); ?>"
                                            <?php echo e(in_array($value->id, $rolePermissions) ? 'checked' : ''); ?>>
                                        <label for="check-s-<?php echo e($value->id); ?>"
                                            class="form-label text-base m-0"><?php echo e($value->name); ?></label>
                                    </div>
                                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                            </div>
                        </div>
                    </div>
                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
            </div>
            <div class="flex justify-end mt-10">
                <button type="submit" class="btn b-solid btn-primary-solid dk-theme-card-square">
                    <?php echo e(isset($role) ? translate('Update') : translate('Save')); ?>

                </button>
            </div>
        </div>
    </form>
 <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__attributesOriginald7f77a02f879fd4954ea3c39c4e952cb)): ?>
<?php $attributes = $__attributesOriginald7f77a02f879fd4954ea3c39c4e952cb; ?>
<?php unset($__attributesOriginald7f77a02f879fd4954ea3c39c4e952cb); ?>
<?php endif; ?>
<?php if (isset($__componentOriginald7f77a02f879fd4954ea3c39c4e952cb)): ?>
<?php $component = $__componentOriginald7f77a02f879fd4954ea3c39c4e952cb; ?>
<?php unset($__componentOriginald7f77a02f879fd4954ea3c39c4e952cb); ?>
<?php endif; ?>
<?php /**PATH D:\www\edulab\Modules\Roles\resources\views\roles\form.blade.php ENDPATH**/ ?>
